=======
Credits
=======

Development Lead
----------------

* Nekmo <contacto@nekmo.com>


Pypi Warehouse logo
-------------------
Pypi Warehouse logo belongs to Python Software Foundation. All rights reserved.


Contributors
------------

None yet. Why not be the first?
